# Security Policy

## Supported Versions

Please report any vulnerabilities in the last 2 major releases of Menoa

## Reporting a Vulnerability

You may report the vulnerability through the GIthub repository (Security > Report a Vulnerability) or through this email [menoa.85r61@simplelogin.com](menoa.85r61@simplelogin.com). At this time we are unable to offer any kind of reward for discovering vulnerabilities. Please do not open a public issue describing a vulnerability

We will get back to you with the outcome of your report as soon as possible
